Faustina an Henañ - Wikipedia

Mont d’an endalc’had

# Faustina an Henañ

31 yezh

- العربية
- مصرى
- Asturianu
- Български
- Català
- Čeština
- Dansk
- Deutsch
- Ελληνικά
- English
- Español
- Eesti
- Euskara
- Estremeñu
- Suomi
- Français
- Frysk
- Italiano
- 한국어
- Latina
- Nederlands
- Norsk nynorsk
- Polski
- Português
- Русский
- Srpskohrvatski / српскохрватски
- Српски / srpski
- Svenska
- Türkçe
- Українська
- 中文

Kemmañ al liammoù
Eus Wikipedia
Ur pennad Faustina zo ivez.
Faostina an Henañ
Aureus da Faustina an Henañ.

Annia Galeria Faustina, lesanvet Faustina Maior pe Faustina an Henañ (c. 100 - c. 140), a oa un impalaerez roman, pried da Antoninus Pius, impalaer eus 138 da 161.

## He buhez

[kemmañ | kemmañ ar vammenn]

### Bugaleaj

[kemmañ | kemmañ ar vammenn]

Ganet e oa e Roma, en un tiegezh roman eus Hispania. Merc'h e oa d'ar c'honsul Marcus Annius Verus. He mamm, Rupilia Faustina, a oa gournizez d'an impalaer Trajan. Nizez e oa da Vibia Sabina (83 – 136 pe 137), pried an impalaer Hadrian.

C'hoar e oa da Varcus Annius Libo, konsul e 128, ha da Varcus Annius Verus, praetor, marvet e 124, a oa pried da Zomitia Lucilla Minor ha tad da Varcus Aurelius ; ur c'hoar he doa ivez, Annia Cornificia Faustina[1].

### Yaouankiz

[kemmañ | kemmañ ar vammenn]

Dimeziñ a reas da Antoninus Pius etre 110 ha 115. Pevar bugel o doe :

- Marcus Aurelius Fulvius Antoninus (marvet a-raok 138) ;
- Marcus Galerius Aurelius Antoninus (marvet a-raok 138) ;
- Aurelia Fadilla (marvet e 135), pried da Aelius Lamia Silvanus, pe Syllanus ; bugel ebet n'o doe ;
- Annia Galeria Faustina Minor pe Faustina ar Yaouankañ (etre 125 pe 130 ha 175), a voe impalaerez roman ha pried d'he c'henderv Marcus Aurelius, impalaer roman.

## Notennoù

[kemmañ | kemmañ ar vammenn]

1. ↑ Historia Augusta, Buhez de Marcus-Aurelius, 1.

Adtapet diwar « https://br.wikipedia.org/w/index.php?title=Faustina_an_Henañ&oldid=1958641 »
Rummadoù:

- Impalaerezed roman
- Marvioù 140

Faustina an Henañ
Rannbennad nevez